# `nefertari-guards`

[![Build Status](https://travis-ci.org/ramses-tech/nefertari-guards.svg?branch=master)](https://travis-ci.org/ramses-tech/nefertari-guards)
[![Documentation](https://readthedocs.org/projects/nefertari-guards/badge/?version=stable)](http://nefertari-guards.readthedocs.org)

Advanced ACLs for [Nefertari](https://github.com/ramses-tech/nefertari).
